@@ -738,23 +738,25 @@ build_ghworkflow <- function() {
   # Publish
   lines <- c(lines,
     '      - name: Upload artifact',
-    '        uses: actions/upload-artifact@v3',
+    '        uses: actions/upload-artifact@v4',
     '        with:',
     '          name: ghpages',
     '          path: docs',
     '  checkout-and-deploy:',
     '    runs-on: ubuntu-latest',
     '    needs: render',
+    '    permissions:',
+    '      contents: write',
     '    steps:',
     '      - name: Download artifact',
-    '        uses: actions/download-artifact@v3',
+    '        uses: actions/download-artifact@v4',
     '        with:',
     '          name: ghpages',
     '          path: docs',
     '      - name: Deploy to GitHub Pages',
     '        uses: Cecilapp/GitHub-Pages-deploy@v3',
     '        env:',
-    '          GITHUB_TOKEN: ${{ secrets.GH_PAT }}',
+    '          GITHUB_TOKEN: ${{ secrets.GITHUB_TOKEN }}',
     '        with:',
     '          email: ${{ secrets.EMAIL }}',
     '          build_dir: docs'
